@@ -27,3 +27,9 @@ class SlackEventLogger(EventLogger):
 
     def log_event(self, event_name: str, event_text: str) -> None:
         self.slack_client.post_message_to_slack(event_text)
+
+    def log_exception(self, event_name: str, event_text: str, ex: Exception) -> None:
+        # don't send full exception to slack since it can have PHI
+        self.slack_client.post_message_to_slack(
+            f"{event_name}: {event_text} {type(ex)}"
+        )
